%undefine _missing_build_ids_terminate_build

%global git_commit da3e8c998d93754b190ed0ce931d7e40bdbf762e
%global git_shortcommit  %(c=%{git_commit}; echo ${c:0:7})

%global provider        github
%global provider_tld    com
%global project         maistra
%global repo            istio-cni
%global with_debug 0

# https://github.com/maistra/istio-cni
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}

Name:           servicemesh-cni
Version:        1.1.16
Release:        1%{?dist}
Summary:        Istio CNI Plugin
License:        ASL 2.0
URL:            https://%{provider_prefix}

Source0:        https://%{provider_prefix}/archive/%{git_commit}/%{repo}-%{git_commit}.tar.gz
Patch0:         0001-MAISTRA-1460-Update-yaml.v2-to-v2.2.4.patch
Patch1:         0002-MAISTRA-1637-CVE-2020-14040-1.patch
Patch2:         0002-MAISTRA-1637-CVE-2020-14040-2.patch
Patch3:         0002-MAISTRA-1637-CVE-2020-14040-3.patch
Patch4:         0003-MAISTRA-1657-CVE-2020-9283.patch

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  x86_64 ppc64le s390x
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  golang >= 1.9

%description
istio-cni is a Container Network Interface (CNI) Plugin that sets up Istio iptables rules for a Pod.

%prep
rm -rf istio-cni
mkdir -p istio-cni/src/%{provider_prefix}
tar zxf %{SOURCE0} -C istio-cni/src/%{provider_prefix} --strip=1

pushd istio-cni/src/github.com/maistra/istio-cni
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
popd

%build
cd istio-cni
export GOPATH=$(pwd):%{gopath}

pushd src/%{provider_prefix}
make build ISTIO_OUT=bin ISTIO_CNI_RELPATH=github.com/maistra/istio-cni TAG=dummy

%install
rm -rf %{buildroot}
mkdir -p %{buildroot}/opt/cni/bin
cd istio-cni/src/%{provider_prefix}

install -p -m 755 tools/deb/istio-iptables.sh %{buildroot}/opt/cni/bin
install -p -m 755 deployments/kubernetes/install/scripts/install-cni.sh %{buildroot}
install -p -m 644 deployments/kubernetes/install/scripts/filter.jq %{buildroot}
install -p -m 755 deployments/kubernetes/install/scripts/istio-cni.conf.default %{buildroot}/istio-cni.conf.tmp

%if 0%{?with_debug}
	install -p -m 755 bin/istio-cni %{buildroot}/opt/cni/bin
%else
	echo "Dumping dynamic symbols"
	nm -D bin/istio-cni --format=posix --defined-only \
	| awk '{ print $1 }' | sort > dynsyms

	echo "Dumping function symbols"
	nm bin/istio-cni --format=posix --defined-only \
	| awk '{ if ($2 == "T" || $2 == "t" || $2 == "D") print $1 }' \
	| sort > funcsyms

	echo "Grabbing other function symbols"
	comm -13 dynsyms funcsyms > keep_symbols

	echo "Removing unnecessary debug info"
	COMPRESSED_NAME=istio_cni_debuginfo

	objcopy -S --remove-section .gdb_index --remove-section .comment \
	--keep-symbols=keep_symbols bin/istio-cni  $COMPRESSED_NAME

	echo "Stripping binary"
	mkdir stripped
	strip -o stripped/istio-cni -s bin/istio-cni

	echo "Compressing debugdata"
	xz $COMPRESSED_NAME

	echo "Injecting compressed data into .gnu_debugdata"
	objcopy --add-section .gnu_debugdata=$COMPRESSED_NAME.xz stripped/istio-cni

	cp -pav stripped/istio-cni %{buildroot}/opt/cni/bin
%endif

%files
%license istio-cni/src/%{provider_prefix}/LICENSE
%doc     istio-cni/src/%{provider_prefix}/README.md

/opt/cni/bin/istio-cni
/opt/cni/bin/istio-iptables.sh
/install-cni.sh
/filter.jq
/istio-cni.conf.tmp


%changelog
* Thu Jun 17 2021 Product Release - 1.1.16-1
- Update to latest release

* Sat May 15 2021 Product Release - 1.1.15-1
- Update to latest release

* Fri May 07 2021 Product Release - 1.1.14-1
- Update to latest release

* Sun Apr 11 2021 Product Release - 1.1.13-1
- Update to latest release

* Tue Jan 26 2021 Product Release - 1.1.12-2
- Update to latest release

* Tue Jan 19 2021 Product Release - 1.1.12-1
- Update to latest release

* Mon Dec 14 2020 Product Release - 1.1.11-2
- Update to latest release

* Mon Dec 14 2020 Product Release - 1.1.11-1
- Update to latest release

* Sat Oct 10 2020 Product Release - 1.1.10-1
- Update to latest release

* Thu Sep 24 2020 Product Release - 1.1.9-1
- Update to latest release

* Fri Sep 11 2020 Product Release - 1.1.8-1
- Update to latest release

* Sat Aug 08 2020 Product Release - 1.1.7-1
- Update to latest release

* Mon Aug 03 2020 Product Release - 1.1.6-1
- Update to latest release

* Fri Jul 17 2020 Product Release - 1.1.5-1
- Update to latest release

* Fri Jun 26 2020 Product Release - 1.1.4-2
- Update to latest release

* Wed Jun 24 2020 Product Release - 1.1.4-1
- Update to latest release

* Mon Jun 15 2020 Product Release - 1.1.3-3
- Update to latest release

* Mon Jun 15 2020 Product Release - 1.1.3-2
- Update to latest release

* Wed Jun 03 2020 Product Release - 1.1.3-1
- Update to latest release

* Mon May 11 2020 Product Release - 1.1.2-2
- Update to latest release

* Mon May 11 2020 Product Release - 1.1.1-1
- Update to latest release

* Wed Apr 22 2020 Product Release - 1.1.1-2
- Update to latest release

* Wed Apr 01 2020 Product Release - 1.1.0-3
- Update to latest release

* Tue Mar 31 2020 Product Release - 1.1.0-2
- Update to latest release

* Tue Mar 31 2020 Product Release - 1.1.0-1
- Update to latest release

